from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RedeemerPurpose(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    REDEEMER_PURPOSE_UNSPECIFIED: _ClassVar[RedeemerPurpose]
    REDEEMER_PURPOSE_SPEND: _ClassVar[RedeemerPurpose]
    REDEEMER_PURPOSE_MINT: _ClassVar[RedeemerPurpose]
    REDEEMER_PURPOSE_CERT: _ClassVar[RedeemerPurpose]
    REDEEMER_PURPOSE_REWARD: _ClassVar[RedeemerPurpose]

class MirSource(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MIR_SOURCE_UNSPECIFIED: _ClassVar[MirSource]
    MIR_SOURCE_RESERVES: _ClassVar[MirSource]
    MIR_SOURCE_TREASURY: _ClassVar[MirSource]
REDEEMER_PURPOSE_UNSPECIFIED: RedeemerPurpose
REDEEMER_PURPOSE_SPEND: RedeemerPurpose
REDEEMER_PURPOSE_MINT: RedeemerPurpose
REDEEMER_PURPOSE_CERT: RedeemerPurpose
REDEEMER_PURPOSE_REWARD: RedeemerPurpose
MIR_SOURCE_UNSPECIFIED: MirSource
MIR_SOURCE_RESERVES: MirSource
MIR_SOURCE_TREASURY: MirSource

class Redeemer(_message.Message):
    __slots__ = ("purpose", "payload")
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    purpose: RedeemerPurpose
    payload: PlutusData
    def __init__(self, purpose: _Optional[_Union[RedeemerPurpose, str]] = ..., payload: _Optional[_Union[PlutusData, _Mapping]] = ...) -> None: ...

class TxInput(_message.Message):
    __slots__ = ("tx_hash", "output_index", "as_output", "redeemer")
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_INDEX_FIELD_NUMBER: _ClassVar[int]
    AS_OUTPUT_FIELD_NUMBER: _ClassVar[int]
    REDEEMER_FIELD_NUMBER: _ClassVar[int]
    tx_hash: bytes
    output_index: int
    as_output: TxOutput
    redeemer: Redeemer
    def __init__(self, tx_hash: _Optional[bytes] = ..., output_index: _Optional[int] = ..., as_output: _Optional[_Union[TxOutput, _Mapping]] = ..., redeemer: _Optional[_Union[Redeemer, _Mapping]] = ...) -> None: ...

class TxOutput(_message.Message):
    __slots__ = ("address", "coin", "assets", "datum", "script")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COIN_FIELD_NUMBER: _ClassVar[int]
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    DATUM_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    coin: int
    assets: _containers.RepeatedCompositeFieldContainer[Multiasset]
    datum: Datum
    script: Script
    def __init__(self, address: _Optional[bytes] = ..., coin: _Optional[int] = ..., assets: _Optional[_Iterable[_Union[Multiasset, _Mapping]]] = ..., datum: _Optional[_Union[Datum, _Mapping]] = ..., script: _Optional[_Union[Script, _Mapping]] = ...) -> None: ...

class Datum(_message.Message):
    __slots__ = ("hash", "payload", "original_cbor")
    HASH_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_CBOR_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    payload: PlutusData
    original_cbor: bytes
    def __init__(self, hash: _Optional[bytes] = ..., payload: _Optional[_Union[PlutusData, _Mapping]] = ..., original_cbor: _Optional[bytes] = ...) -> None: ...

class Asset(_message.Message):
    __slots__ = ("name", "output_coin", "mint_coin")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_COIN_FIELD_NUMBER: _ClassVar[int]
    MINT_COIN_FIELD_NUMBER: _ClassVar[int]
    name: bytes
    output_coin: int
    mint_coin: int
    def __init__(self, name: _Optional[bytes] = ..., output_coin: _Optional[int] = ..., mint_coin: _Optional[int] = ...) -> None: ...

class Multiasset(_message.Message):
    __slots__ = ("policy_id", "assets", "redeemer")
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    REDEEMER_FIELD_NUMBER: _ClassVar[int]
    policy_id: bytes
    assets: _containers.RepeatedCompositeFieldContainer[Asset]
    redeemer: Redeemer
    def __init__(self, policy_id: _Optional[bytes] = ..., assets: _Optional[_Iterable[_Union[Asset, _Mapping]]] = ..., redeemer: _Optional[_Union[Redeemer, _Mapping]] = ...) -> None: ...

class TxValidity(_message.Message):
    __slots__ = ("start", "ttl")
    START_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    start: int
    ttl: int
    def __init__(self, start: _Optional[int] = ..., ttl: _Optional[int] = ...) -> None: ...

class Collateral(_message.Message):
    __slots__ = ("collateral", "collateral_return", "total_collateral")
    COLLATERAL_FIELD_NUMBER: _ClassVar[int]
    COLLATERAL_RETURN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COLLATERAL_FIELD_NUMBER: _ClassVar[int]
    collateral: _containers.RepeatedCompositeFieldContainer[TxInput]
    collateral_return: TxOutput
    total_collateral: int
    def __init__(self, collateral: _Optional[_Iterable[_Union[TxInput, _Mapping]]] = ..., collateral_return: _Optional[_Union[TxOutput, _Mapping]] = ..., total_collateral: _Optional[int] = ...) -> None: ...

class Withdrawal(_message.Message):
    __slots__ = ("reward_account", "coin", "redeemer")
    REWARD_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    COIN_FIELD_NUMBER: _ClassVar[int]
    REDEEMER_FIELD_NUMBER: _ClassVar[int]
    reward_account: bytes
    coin: int
    redeemer: Redeemer
    def __init__(self, reward_account: _Optional[bytes] = ..., coin: _Optional[int] = ..., redeemer: _Optional[_Union[Redeemer, _Mapping]] = ...) -> None: ...

class WitnessSet(_message.Message):
    __slots__ = ("vkeywitness", "script", "plutus_datums")
    VKEYWITNESS_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    PLUTUS_DATUMS_FIELD_NUMBER: _ClassVar[int]
    vkeywitness: _containers.RepeatedCompositeFieldContainer[VKeyWitness]
    script: _containers.RepeatedCompositeFieldContainer[Script]
    plutus_datums: _containers.RepeatedCompositeFieldContainer[PlutusData]
    def __init__(self, vkeywitness: _Optional[_Iterable[_Union[VKeyWitness, _Mapping]]] = ..., script: _Optional[_Iterable[_Union[Script, _Mapping]]] = ..., plutus_datums: _Optional[_Iterable[_Union[PlutusData, _Mapping]]] = ...) -> None: ...

class AuxData(_message.Message):
    __slots__ = ("metadata", "scripts")
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    metadata: _containers.RepeatedCompositeFieldContainer[Metadata]
    scripts: _containers.RepeatedCompositeFieldContainer[Script]
    def __init__(self, metadata: _Optional[_Iterable[_Union[Metadata, _Mapping]]] = ..., scripts: _Optional[_Iterable[_Union[Script, _Mapping]]] = ...) -> None: ...

class Tx(_message.Message):
    __slots__ = ("inputs", "outputs", "certificates", "withdrawals", "mint", "reference_inputs", "witnesses", "collateral", "fee", "validity", "successful", "auxiliary", "hash")
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATES_FIELD_NUMBER: _ClassVar[int]
    WITHDRAWALS_FIELD_NUMBER: _ClassVar[int]
    MINT_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_INPUTS_FIELD_NUMBER: _ClassVar[int]
    WITNESSES_FIELD_NUMBER: _ClassVar[int]
    COLLATERAL_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    VALIDITY_FIELD_NUMBER: _ClassVar[int]
    SUCCESSFUL_FIELD_NUMBER: _ClassVar[int]
    AUXILIARY_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    inputs: _containers.RepeatedCompositeFieldContainer[TxInput]
    outputs: _containers.RepeatedCompositeFieldContainer[TxOutput]
    certificates: _containers.RepeatedCompositeFieldContainer[Certificate]
    withdrawals: _containers.RepeatedCompositeFieldContainer[Withdrawal]
    mint: _containers.RepeatedCompositeFieldContainer[Multiasset]
    reference_inputs: _containers.RepeatedCompositeFieldContainer[TxInput]
    witnesses: WitnessSet
    collateral: Collateral
    fee: int
    validity: TxValidity
    successful: bool
    auxiliary: AuxData
    hash: bytes
    def __init__(self, inputs: _Optional[_Iterable[_Union[TxInput, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[TxOutput, _Mapping]]] = ..., certificates: _Optional[_Iterable[_Union[Certificate, _Mapping]]] = ..., withdrawals: _Optional[_Iterable[_Union[Withdrawal, _Mapping]]] = ..., mint: _Optional[_Iterable[_Union[Multiasset, _Mapping]]] = ..., reference_inputs: _Optional[_Iterable[_Union[TxInput, _Mapping]]] = ..., witnesses: _Optional[_Union[WitnessSet, _Mapping]] = ..., collateral: _Optional[_Union[Collateral, _Mapping]] = ..., fee: _Optional[int] = ..., validity: _Optional[_Union[TxValidity, _Mapping]] = ..., successful: bool = ..., auxiliary: _Optional[_Union[AuxData, _Mapping]] = ..., hash: _Optional[bytes] = ...) -> None: ...

class BlockHeader(_message.Message):
    __slots__ = ("slot", "hash", "height")
    SLOT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    slot: int
    hash: bytes
    height: int
    def __init__(self, slot: _Optional[int] = ..., hash: _Optional[bytes] = ..., height: _Optional[int] = ...) -> None: ...

class BlockBody(_message.Message):
    __slots__ = ("tx",)
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: _containers.RepeatedCompositeFieldContainer[Tx]
    def __init__(self, tx: _Optional[_Iterable[_Union[Tx, _Mapping]]] = ...) -> None: ...

class Block(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: BlockHeader
    body: BlockBody
    def __init__(self, header: _Optional[_Union[BlockHeader, _Mapping]] = ..., body: _Optional[_Union[BlockBody, _Mapping]] = ...) -> None: ...

class VKeyWitness(_message.Message):
    __slots__ = ("vkey", "signature")
    VKEY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    vkey: bytes
    signature: bytes
    def __init__(self, vkey: _Optional[bytes] = ..., signature: _Optional[bytes] = ...) -> None: ...

class NativeScript(_message.Message):
    __slots__ = ("script_pubkey", "script_all", "script_any", "script_n_of_k", "invalid_before", "invalid_hereafter")
    SCRIPT_PUBKEY_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_ALL_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_ANY_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_N_OF_K_FIELD_NUMBER: _ClassVar[int]
    INVALID_BEFORE_FIELD_NUMBER: _ClassVar[int]
    INVALID_HEREAFTER_FIELD_NUMBER: _ClassVar[int]
    script_pubkey: bytes
    script_all: NativeScriptList
    script_any: NativeScriptList
    script_n_of_k: ScriptNOfK
    invalid_before: int
    invalid_hereafter: int
    def __init__(self, script_pubkey: _Optional[bytes] = ..., script_all: _Optional[_Union[NativeScriptList, _Mapping]] = ..., script_any: _Optional[_Union[NativeScriptList, _Mapping]] = ..., script_n_of_k: _Optional[_Union[ScriptNOfK, _Mapping]] = ..., invalid_before: _Optional[int] = ..., invalid_hereafter: _Optional[int] = ...) -> None: ...

class NativeScriptList(_message.Message):
    __slots__ = ("items",)
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[NativeScript]
    def __init__(self, items: _Optional[_Iterable[_Union[NativeScript, _Mapping]]] = ...) -> None: ...

class ScriptNOfK(_message.Message):
    __slots__ = ("k", "scripts")
    K_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    k: int
    scripts: _containers.RepeatedCompositeFieldContainer[NativeScript]
    def __init__(self, k: _Optional[int] = ..., scripts: _Optional[_Iterable[_Union[NativeScript, _Mapping]]] = ...) -> None: ...

class Constr(_message.Message):
    __slots__ = ("tag", "any_constructor", "fields")
    TAG_FIELD_NUMBER: _ClassVar[int]
    ANY_CONSTRUCTOR_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    tag: int
    any_constructor: int
    fields: _containers.RepeatedCompositeFieldContainer[PlutusData]
    def __init__(self, tag: _Optional[int] = ..., any_constructor: _Optional[int] = ..., fields: _Optional[_Iterable[_Union[PlutusData, _Mapping]]] = ...) -> None: ...

class BigInt(_message.Message):
    __slots__ = ("int", "big_u_int", "big_n_int")
    INT_FIELD_NUMBER: _ClassVar[int]
    BIG_U_INT_FIELD_NUMBER: _ClassVar[int]
    BIG_N_INT_FIELD_NUMBER: _ClassVar[int]
    int: int
    big_u_int: bytes
    big_n_int: bytes
    def __init__(self, int: _Optional[int] = ..., big_u_int: _Optional[bytes] = ..., big_n_int: _Optional[bytes] = ...) -> None: ...

class PlutusDataPair(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: PlutusData
    value: PlutusData
    def __init__(self, key: _Optional[_Union[PlutusData, _Mapping]] = ..., value: _Optional[_Union[PlutusData, _Mapping]] = ...) -> None: ...

class PlutusData(_message.Message):
    __slots__ = ("constr", "map", "big_int", "bounded_bytes", "array")
    CONSTR_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    BIG_INT_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_BYTES_FIELD_NUMBER: _ClassVar[int]
    ARRAY_FIELD_NUMBER: _ClassVar[int]
    constr: Constr
    map: PlutusDataMap
    big_int: BigInt
    bounded_bytes: bytes
    array: PlutusDataArray
    def __init__(self, constr: _Optional[_Union[Constr, _Mapping]] = ..., map: _Optional[_Union[PlutusDataMap, _Mapping]] = ..., big_int: _Optional[_Union[BigInt, _Mapping]] = ..., bounded_bytes: _Optional[bytes] = ..., array: _Optional[_Union[PlutusDataArray, _Mapping]] = ...) -> None: ...

class PlutusDataMap(_message.Message):
    __slots__ = ("pairs",)
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    pairs: _containers.RepeatedCompositeFieldContainer[PlutusDataPair]
    def __init__(self, pairs: _Optional[_Iterable[_Union[PlutusDataPair, _Mapping]]] = ...) -> None: ...

class PlutusDataArray(_message.Message):
    __slots__ = ("items",)
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[PlutusData]
    def __init__(self, items: _Optional[_Iterable[_Union[PlutusData, _Mapping]]] = ...) -> None: ...

class Script(_message.Message):
    __slots__ = ("native", "plutus_v1", "plutus_v2")
    NATIVE_FIELD_NUMBER: _ClassVar[int]
    PLUTUS_V1_FIELD_NUMBER: _ClassVar[int]
    PLUTUS_V2_FIELD_NUMBER: _ClassVar[int]
    native: NativeScript
    plutus_v1: bytes
    plutus_v2: bytes
    def __init__(self, native: _Optional[_Union[NativeScript, _Mapping]] = ..., plutus_v1: _Optional[bytes] = ..., plutus_v2: _Optional[bytes] = ...) -> None: ...

class Metadatum(_message.Message):
    __slots__ = ("int", "bytes", "text", "array", "map")
    INT_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    ARRAY_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    int: int
    bytes: bytes
    text: str
    array: MetadatumArray
    map: MetadatumMap
    def __init__(self, int: _Optional[int] = ..., bytes: _Optional[bytes] = ..., text: _Optional[str] = ..., array: _Optional[_Union[MetadatumArray, _Mapping]] = ..., map: _Optional[_Union[MetadatumMap, _Mapping]] = ...) -> None: ...

class MetadatumArray(_message.Message):
    __slots__ = ("items",)
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[Metadatum]
    def __init__(self, items: _Optional[_Iterable[_Union[Metadatum, _Mapping]]] = ...) -> None: ...

class MetadatumMap(_message.Message):
    __slots__ = ("pairs",)
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    pairs: _containers.RepeatedCompositeFieldContainer[MetadatumPair]
    def __init__(self, pairs: _Optional[_Iterable[_Union[MetadatumPair, _Mapping]]] = ...) -> None: ...

class MetadatumPair(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: Metadatum
    value: Metadatum
    def __init__(self, key: _Optional[_Union[Metadatum, _Mapping]] = ..., value: _Optional[_Union[Metadatum, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("label", "value")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    label: int
    value: Metadatum
    def __init__(self, label: _Optional[int] = ..., value: _Optional[_Union[Metadatum, _Mapping]] = ...) -> None: ...

class StakeCredential(_message.Message):
    __slots__ = ("addr_key_hash", "script_hash")
    ADDR_KEY_HASH_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_HASH_FIELD_NUMBER: _ClassVar[int]
    addr_key_hash: bytes
    script_hash: bytes
    def __init__(self, addr_key_hash: _Optional[bytes] = ..., script_hash: _Optional[bytes] = ...) -> None: ...

class RationalNumber(_message.Message):
    __slots__ = ("numerator", "denominator")
    NUMERATOR_FIELD_NUMBER: _ClassVar[int]
    DENOMINATOR_FIELD_NUMBER: _ClassVar[int]
    numerator: int
    denominator: int
    def __init__(self, numerator: _Optional[int] = ..., denominator: _Optional[int] = ...) -> None: ...

class Relay(_message.Message):
    __slots__ = ("ip_v4", "ip_v6", "dns_name", "port")
    IP_V4_FIELD_NUMBER: _ClassVar[int]
    IP_V6_FIELD_NUMBER: _ClassVar[int]
    DNS_NAME_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    ip_v4: bytes
    ip_v6: bytes
    dns_name: str
    port: int
    def __init__(self, ip_v4: _Optional[bytes] = ..., ip_v6: _Optional[bytes] = ..., dns_name: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...

class PoolMetadata(_message.Message):
    __slots__ = ("url", "hash")
    URL_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    url: str
    hash: bytes
    def __init__(self, url: _Optional[str] = ..., hash: _Optional[bytes] = ...) -> None: ...

class Certificate(_message.Message):
    __slots__ = ("stake_registration", "stake_deregistration", "stake_delegation", "pool_registration", "pool_retirement", "genesis_key_delegation", "mir_cert", "redeemer")
    STAKE_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    STAKE_DEREGISTRATION_FIELD_NUMBER: _ClassVar[int]
    STAKE_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    POOL_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    POOL_RETIREMENT_FIELD_NUMBER: _ClassVar[int]
    GENESIS_KEY_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    MIR_CERT_FIELD_NUMBER: _ClassVar[int]
    REDEEMER_FIELD_NUMBER: _ClassVar[int]
    stake_registration: StakeCredential
    stake_deregistration: StakeCredential
    stake_delegation: StakeDelegationCert
    pool_registration: PoolRegistrationCert
    pool_retirement: PoolRetirementCert
    genesis_key_delegation: GenesisKeyDelegationCert
    mir_cert: MirCert
    redeemer: Redeemer
    def __init__(self, stake_registration: _Optional[_Union[StakeCredential, _Mapping]] = ..., stake_deregistration: _Optional[_Union[StakeCredential, _Mapping]] = ..., stake_delegation: _Optional[_Union[StakeDelegationCert, _Mapping]] = ..., pool_registration: _Optional[_Union[PoolRegistrationCert, _Mapping]] = ..., pool_retirement: _Optional[_Union[PoolRetirementCert, _Mapping]] = ..., genesis_key_delegation: _Optional[_Union[GenesisKeyDelegationCert, _Mapping]] = ..., mir_cert: _Optional[_Union[MirCert, _Mapping]] = ..., redeemer: _Optional[_Union[Redeemer, _Mapping]] = ...) -> None: ...

class StakeDelegationCert(_message.Message):
    __slots__ = ("stake_credential", "pool_keyhash")
    STAKE_CREDENTIAL_FIELD_NUMBER: _ClassVar[int]
    POOL_KEYHASH_FIELD_NUMBER: _ClassVar[int]
    stake_credential: StakeCredential
    pool_keyhash: bytes
    def __init__(self, stake_credential: _Optional[_Union[StakeCredential, _Mapping]] = ..., pool_keyhash: _Optional[bytes] = ...) -> None: ...

class PoolRegistrationCert(_message.Message):
    __slots__ = ("operator", "vrf_keyhash", "pledge", "cost", "margin", "reward_account", "pool_owners", "relays", "pool_metadata")
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    VRF_KEYHASH_FIELD_NUMBER: _ClassVar[int]
    PLEDGE_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    MARGIN_FIELD_NUMBER: _ClassVar[int]
    REWARD_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    POOL_OWNERS_FIELD_NUMBER: _ClassVar[int]
    RELAYS_FIELD_NUMBER: _ClassVar[int]
    POOL_METADATA_FIELD_NUMBER: _ClassVar[int]
    operator: bytes
    vrf_keyhash: bytes
    pledge: int
    cost: int
    margin: RationalNumber
    reward_account: bytes
    pool_owners: _containers.RepeatedScalarFieldContainer[bytes]
    relays: _containers.RepeatedCompositeFieldContainer[Relay]
    pool_metadata: PoolMetadata
    def __init__(self, operator: _Optional[bytes] = ..., vrf_keyhash: _Optional[bytes] = ..., pledge: _Optional[int] = ..., cost: _Optional[int] = ..., margin: _Optional[_Union[RationalNumber, _Mapping]] = ..., reward_account: _Optional[bytes] = ..., pool_owners: _Optional[_Iterable[bytes]] = ..., relays: _Optional[_Iterable[_Union[Relay, _Mapping]]] = ..., pool_metadata: _Optional[_Union[PoolMetadata, _Mapping]] = ...) -> None: ...

class PoolRetirementCert(_message.Message):
    __slots__ = ("pool_keyhash", "epoch")
    POOL_KEYHASH_FIELD_NUMBER: _ClassVar[int]
    EPOCH_FIELD_NUMBER: _ClassVar[int]
    pool_keyhash: bytes
    epoch: int
    def __init__(self, pool_keyhash: _Optional[bytes] = ..., epoch: _Optional[int] = ...) -> None: ...

class GenesisKeyDelegationCert(_message.Message):
    __slots__ = ("genesis_hash", "genesis_delegate_hash", "vrf_keyhash")
    GENESIS_HASH_FIELD_NUMBER: _ClassVar[int]
    GENESIS_DELEGATE_HASH_FIELD_NUMBER: _ClassVar[int]
    VRF_KEYHASH_FIELD_NUMBER: _ClassVar[int]
    genesis_hash: bytes
    genesis_delegate_hash: bytes
    vrf_keyhash: bytes
    def __init__(self, genesis_hash: _Optional[bytes] = ..., genesis_delegate_hash: _Optional[bytes] = ..., vrf_keyhash: _Optional[bytes] = ...) -> None: ...

class MirTarget(_message.Message):
    __slots__ = ("stake_credential", "delta_coin")
    STAKE_CREDENTIAL_FIELD_NUMBER: _ClassVar[int]
    DELTA_COIN_FIELD_NUMBER: _ClassVar[int]
    stake_credential: StakeCredential
    delta_coin: int
    def __init__(self, stake_credential: _Optional[_Union[StakeCredential, _Mapping]] = ..., delta_coin: _Optional[int] = ...) -> None: ...

class MirCert(_message.Message):
    __slots__ = ("to", "other_pot")
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    OTHER_POT_FIELD_NUMBER: _ClassVar[int]
    to: _containers.RepeatedCompositeFieldContainer[MirTarget]
    other_pot: int
    def __init__(self, to: _Optional[_Iterable[_Union[MirTarget, _Mapping]]] = ..., other_pot: _Optional[int] = ..., **kwargs) -> None: ...

class AddressPattern(_message.Message):
    __slots__ = ("exact_address", "payment_part", "delegation_part")
    EXACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_PART_FIELD_NUMBER: _ClassVar[int]
    DELEGATION_PART_FIELD_NUMBER: _ClassVar[int]
    exact_address: bytes
    payment_part: bytes
    delegation_part: bytes
    def __init__(self, exact_address: _Optional[bytes] = ..., payment_part: _Optional[bytes] = ..., delegation_part: _Optional[bytes] = ...) -> None: ...

class AssetPattern(_message.Message):
    __slots__ = ("policy_id", "asset_name")
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    ASSET_NAME_FIELD_NUMBER: _ClassVar[int]
    policy_id: bytes
    asset_name: bytes
    def __init__(self, policy_id: _Optional[bytes] = ..., asset_name: _Optional[bytes] = ...) -> None: ...

class TxOutputPattern(_message.Message):
    __slots__ = ("address", "asset")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ASSET_FIELD_NUMBER: _ClassVar[int]
    address: AddressPattern
    asset: AssetPattern
    def __init__(self, address: _Optional[_Union[AddressPattern, _Mapping]] = ..., asset: _Optional[_Union[AssetPattern, _Mapping]] = ...) -> None: ...

class TxPattern(_message.Message):
    __slots__ = ("consumes", "produces", "has_address", "moves_asset", "mints_asset")
    CONSUMES_FIELD_NUMBER: _ClassVar[int]
    PRODUCES_FIELD_NUMBER: _ClassVar[int]
    HAS_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MOVES_ASSET_FIELD_NUMBER: _ClassVar[int]
    MINTS_ASSET_FIELD_NUMBER: _ClassVar[int]
    consumes: TxOutputPattern
    produces: TxOutputPattern
    has_address: AddressPattern
    moves_asset: AssetPattern
    mints_asset: AssetPattern
    def __init__(self, consumes: _Optional[_Union[TxOutputPattern, _Mapping]] = ..., produces: _Optional[_Union[TxOutputPattern, _Mapping]] = ..., has_address: _Optional[_Union[AddressPattern, _Mapping]] = ..., moves_asset: _Optional[_Union[AssetPattern, _Mapping]] = ..., mints_asset: _Optional[_Union[AssetPattern, _Mapping]] = ...) -> None: ...

class ExUnits(_message.Message):
    __slots__ = ("steps", "memory")
    STEPS_FIELD_NUMBER: _ClassVar[int]
    MEMORY_FIELD_NUMBER: _ClassVar[int]
    steps: int
    memory: int
    def __init__(self, steps: _Optional[int] = ..., memory: _Optional[int] = ...) -> None: ...

class ExPrices(_message.Message):
    __slots__ = ("steps", "memory")
    STEPS_FIELD_NUMBER: _ClassVar[int]
    MEMORY_FIELD_NUMBER: _ClassVar[int]
    steps: RationalNumber
    memory: RationalNumber
    def __init__(self, steps: _Optional[_Union[RationalNumber, _Mapping]] = ..., memory: _Optional[_Union[RationalNumber, _Mapping]] = ...) -> None: ...

class ProtocolVersion(_message.Message):
    __slots__ = ("major", "minor")
    MAJOR_FIELD_NUMBER: _ClassVar[int]
    MINOR_FIELD_NUMBER: _ClassVar[int]
    major: int
    minor: int
    def __init__(self, major: _Optional[int] = ..., minor: _Optional[int] = ...) -> None: ...

class CostModel(_message.Message):
    __slots__ = ("values",)
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, values: _Optional[_Iterable[int]] = ...) -> None: ...

class CostModels(_message.Message):
    __slots__ = ("plutus_v1", "plutus_v2")
    PLUTUS_V1_FIELD_NUMBER: _ClassVar[int]
    PLUTUS_V2_FIELD_NUMBER: _ClassVar[int]
    plutus_v1: CostModel
    plutus_v2: CostModel
    def __init__(self, plutus_v1: _Optional[_Union[CostModel, _Mapping]] = ..., plutus_v2: _Optional[_Union[CostModel, _Mapping]] = ...) -> None: ...

class PParams(_message.Message):
    __slots__ = ("coins_per_utxo_byte", "max_tx_size", "min_fee_coefficient", "min_fee_constant", "max_block_body_size", "max_block_header_size", "stake_key_deposit", "pool_deposit", "pool_retirement_epoch_bound", "desired_number_of_pools", "pool_influence", "monetary_expansion", "treasury_expansion", "min_pool_cost", "protocol_version", "max_value_size", "collateral_percentage", "max_collateral_inputs", "cost_models", "prices", "max_execution_units_per_transaction", "max_execution_units_per_block")
    COINS_PER_UTXO_BYTE_FIELD_NUMBER: _ClassVar[int]
    MAX_TX_SIZE_FIELD_NUMBER: _ClassVar[int]
    MIN_FEE_COEFFICIENT_FIELD_NUMBER: _ClassVar[int]
    MIN_FEE_CONSTANT_FIELD_NUMBER: _ClassVar[int]
    MAX_BLOCK_BODY_SIZE_FIELD_NUMBER: _ClassVar[int]
    MAX_BLOCK_HEADER_SIZE_FIELD_NUMBER: _ClassVar[int]
    STAKE_KEY_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    POOL_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    POOL_RETIREMENT_EPOCH_BOUND_FIELD_NUMBER: _ClassVar[int]
    DESIRED_NUMBER_OF_POOLS_FIELD_NUMBER: _ClassVar[int]
    POOL_INFLUENCE_FIELD_NUMBER: _ClassVar[int]
    MONETARY_EXPANSION_FIELD_NUMBER: _ClassVar[int]
    TREASURY_EXPANSION_FIELD_NUMBER: _ClassVar[int]
    MIN_POOL_COST_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    MAX_VALUE_SIZE_FIELD_NUMBER: _ClassVar[int]
    COLLATERAL_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    MAX_COLLATERAL_INPUTS_FIELD_NUMBER: _ClassVar[int]
    COST_MODELS_FIELD_NUMBER: _ClassVar[int]
    PRICES_FIELD_NUMBER: _ClassVar[int]
    MAX_EXECUTION_UNITS_PER_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    MAX_EXECUTION_UNITS_PER_BLOCK_FIELD_NUMBER: _ClassVar[int]
    coins_per_utxo_byte: int
    max_tx_size: int
    min_fee_coefficient: int
    min_fee_constant: int
    max_block_body_size: int
    max_block_header_size: int
    stake_key_deposit: int
    pool_deposit: int
    pool_retirement_epoch_bound: int
    desired_number_of_pools: int
    pool_influence: RationalNumber
    monetary_expansion: RationalNumber
    treasury_expansion: RationalNumber
    min_pool_cost: int
    protocol_version: ProtocolVersion
    max_value_size: int
    collateral_percentage: int
    max_collateral_inputs: int
    cost_models: CostModels
    prices: ExPrices
    max_execution_units_per_transaction: ExUnits
    max_execution_units_per_block: ExUnits
    def __init__(self, coins_per_utxo_byte: _Optional[int] = ..., max_tx_size: _Optional[int] = ..., min_fee_coefficient: _Optional[int] = ..., min_fee_constant: _Optional[int] = ..., max_block_body_size: _Optional[int] = ..., max_block_header_size: _Optional[int] = ..., stake_key_deposit: _Optional[int] = ..., pool_deposit: _Optional[int] = ..., pool_retirement_epoch_bound: _Optional[int] = ..., desired_number_of_pools: _Optional[int] = ..., pool_influence: _Optional[_Union[RationalNumber, _Mapping]] = ..., monetary_expansion: _Optional[_Union[RationalNumber, _Mapping]] = ..., treasury_expansion: _Optional[_Union[RationalNumber, _Mapping]] = ..., min_pool_cost: _Optional[int] = ..., protocol_version: _Optional[_Union[ProtocolVersion, _Mapping]] = ..., max_value_size: _Optional[int] = ..., collateral_percentage: _Optional[int] = ..., max_collateral_inputs: _Optional[int] = ..., cost_models: _Optional[_Union[CostModels, _Mapping]] = ..., prices: _Optional[_Union[ExPrices, _Mapping]] = ..., max_execution_units_per_transaction: _Optional[_Union[ExUnits, _Mapping]] = ..., max_execution_units_per_block: _Optional[_Union[ExUnits, _Mapping]] = ...) -> None: ...

class EvalError(_message.Message):
    __slots__ = ("msg",)
    MSG_FIELD_NUMBER: _ClassVar[int]
    msg: str
    def __init__(self, msg: _Optional[str] = ...) -> None: ...

class EvalTrace(_message.Message):
    __slots__ = ("msg",)
    MSG_FIELD_NUMBER: _ClassVar[int]
    msg: str
    def __init__(self, msg: _Optional[str] = ...) -> None: ...

class TxEval(_message.Message):
    __slots__ = ("fee", "ex_units", "errors", "traces")
    FEE_FIELD_NUMBER: _ClassVar[int]
    EX_UNITS_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    TRACES_FIELD_NUMBER: _ClassVar[int]
    fee: int
    ex_units: ExUnits
    errors: _containers.RepeatedCompositeFieldContainer[EvalError]
    traces: _containers.RepeatedCompositeFieldContainer[EvalTrace]
    def __init__(self, fee: _Optional[int] = ..., ex_units: _Optional[_Union[ExUnits, _Mapping]] = ..., errors: _Optional[_Iterable[_Union[EvalError, _Mapping]]] = ..., traces: _Optional[_Iterable[_Union[EvalTrace, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from utxorpc_spec.utxorpc.v1alpha.sync import sync_pb2 as utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2


class SyncServiceStub(object):
    """Service definition for syncing chain data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FetchBlock = channel.unary_unary(
                '/utxorpc.v1alpha.sync.SyncService/FetchBlock',
                request_serializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FetchBlockRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FetchBlockResponse.FromString,
                _registered_method=True)
        self.DumpHistory = channel.unary_unary(
                '/utxorpc.v1alpha.sync.SyncService/DumpHistory',
                request_serializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.DumpHistoryRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.DumpHistoryResponse.FromString,
                _registered_method=True)
        self.FollowTip = channel.unary_stream(
                '/utxorpc.v1alpha.sync.SyncService/FollowTip',
                request_serializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FollowTipRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FollowTipResponse.FromString,
                _registered_method=True)


class SyncServiceServicer(object):
    """Service definition for syncing chain data.
    """

    def FetchBlock(self, request, context):
        """Fetch a block by its reference.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DumpHistory(self, request, context):
        """Dump the block history.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FollowTip(self, request, context):
        """Follow the tip of the blockchain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FetchBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchBlock,
                    request_deserializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FetchBlockRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FetchBlockResponse.SerializeToString,
            ),
            'DumpHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.DumpHistory,
                    request_deserializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.DumpHistoryRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.DumpHistoryResponse.SerializeToString,
            ),
            'FollowTip': grpc.unary_stream_rpc_method_handler(
                    servicer.FollowTip,
                    request_deserializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FollowTipRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FollowTipResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'utxorpc.v1alpha.sync.SyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('utxorpc.v1alpha.sync.SyncService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SyncService(object):
    """Service definition for syncing chain data.
    """

    @staticmethod
    def FetchBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.sync.SyncService/FetchBlock',
            utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FetchBlockRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FetchBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DumpHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.sync.SyncService/DumpHistory',
            utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.DumpHistoryRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.DumpHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FollowTip(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/utxorpc.v1alpha.sync.SyncService/FollowTip',
            utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FollowTipRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_sync_dot_sync__pb2.FollowTipResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from utxorpc_spec.utxorpc.v1alpha.submit import submit_pb2 as utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2


class SubmitServiceStub(object):
    """Service definition for submitting transactions and checking their status.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EvalTx = channel.unary_unary(
                '/utxorpc.v1alpha.submit.SubmitService/EvalTx',
                request_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.EvalTxRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.EvalTxResponse.FromString,
                _registered_method=True)
        self.SubmitTx = channel.unary_unary(
                '/utxorpc.v1alpha.submit.SubmitService/SubmitTx',
                request_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.SubmitTxRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.SubmitTxResponse.FromString,
                _registered_method=True)
        self.WaitForTx = channel.unary_stream(
                '/utxorpc.v1alpha.submit.SubmitService/WaitForTx',
                request_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WaitForTxRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WaitForTxResponse.FromString,
                _registered_method=True)
        self.ReadMempool = channel.unary_unary(
                '/utxorpc.v1alpha.submit.SubmitService/ReadMempool',
                request_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.ReadMempoolRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.ReadMempoolResponse.FromString,
                _registered_method=True)
        self.WatchMempool = channel.unary_stream(
                '/utxorpc.v1alpha.submit.SubmitService/WatchMempool',
                request_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WatchMempoolRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WatchMempoolResponse.FromString,
                _registered_method=True)


class SubmitServiceServicer(object):
    """Service definition for submitting transactions and checking their status.
    """

    def EvalTx(self, request, context):
        """Evaluates a transaction without submitting it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitTx(self, request, context):
        """Submit transactions to the blockchain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitForTx(self, request, context):
        """Wait for transactions to reach a certain stage and stream the updates.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadMempool(self, request, context):
        """Returns a point-in-time snapshot of the mempool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchMempool(self, request, context):
        """Stream transactions from the mempool matching the specified predicates.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SubmitServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EvalTx': grpc.unary_unary_rpc_method_handler(
                    servicer.EvalTx,
                    request_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.EvalTxRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.EvalTxResponse.SerializeToString,
            ),
            'SubmitTx': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitTx,
                    request_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.SubmitTxRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.SubmitTxResponse.SerializeToString,
            ),
            'WaitForTx': grpc.unary_stream_rpc_method_handler(
                    servicer.WaitForTx,
                    request_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WaitForTxRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WaitForTxResponse.SerializeToString,
            ),
            'ReadMempool': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadMempool,
                    request_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.ReadMempoolRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.ReadMempoolResponse.SerializeToString,
            ),
            'WatchMempool': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchMempool,
                    request_deserializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WatchMempoolRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WatchMempoolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'utxorpc.v1alpha.submit.SubmitService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('utxorpc.v1alpha.submit.SubmitService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SubmitService(object):
    """Service definition for submitting transactions and checking their status.
    """

    @staticmethod
    def EvalTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.submit.SubmitService/EvalTx',
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.EvalTxRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.EvalTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.submit.SubmitService/SubmitTx',
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.SubmitTxRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.SubmitTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WaitForTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/utxorpc.v1alpha.submit.SubmitService/WaitForTx',
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WaitForTxRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WaitForTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReadMempool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.submit.SubmitService/ReadMempool',
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.ReadMempoolRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.ReadMempoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WatchMempool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/utxorpc.v1alpha.submit.SubmitService/WatchMempool',
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WatchMempoolRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_submit_dot_submit__pb2.WatchMempoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/watch/watch.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/watch/watch.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!utxorpc/v1alpha/watch/watch.proto\x12\x15utxorpc.v1alpha.watch\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"4\n\x08\x42lockRef\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"\\\n\x11\x41nyChainTxPattern\x12>\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.TxPatternH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\xf9\x01\n\x0bTxPredicate\x12>\n\x05match\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.watch.AnyChainTxPatternR\x05match\x12\x34\n\x03not\x18\x02 \x03(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\x03not\x12\x39\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\x05\x61llOf\x12\x39\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\x05\x61nyOf\"\xcc\x01\n\x0eWatchTxRequest\x12@\n\tpredicate\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\tpredicate\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\x12=\n\tintersect\x18\x03 \x03(\x0b\x32\x1f.utxorpc.v1alpha.watch.BlockRefR\tintersect\"N\n\nAnyChainTx\x12\x37\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32\x1b.utxorpc.v1alpha.cardano.TxH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\x8f\x01\n\x0fWatchTxResponse\x12\x39\n\x05\x61pply\x18\x01 \x01(\x0b\x32!.utxorpc.v1alpha.watch.AnyChainTxH\x00R\x05\x61pply\x12\x37\n\x04undo\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.watch.AnyChainTxH\x00R\x04undoB\x08\n\x06\x61\x63tion2j\n\x0cWatchService\x12Z\n\x07WatchTx\x12%.utxorpc.v1alpha.watch.WatchTxRequest\x1a&.utxorpc.v1alpha.watch.WatchTxResponse0\x01\x42\xd2\x01\n\x19\x63om.utxorpc.v1alpha.watchB\nWatchProtoP\x01Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/watch\xa2\x02\x03UVW\xaa\x02\x15Utxorpc.V1alpha.Watch\xca\x02\x15Utxorpc\\V1alpha\\Watch\xe2\x02!Utxorpc\\V1alpha\\Watch\\GPBMetadata\xea\x02\x17Utxorpc::V1alpha::Watchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.watch.watch_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.utxorpc.v1alpha.watchB\nWatchProtoP\001Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/watch\242\002\003UVW\252\002\025Utxorpc.V1alpha.Watch\312\002\025Utxorpc\\V1alpha\\Watch\342\002!Utxorpc\\V1alpha\\Watch\\GPBMetadata\352\002\027Utxorpc::V1alpha::Watch'
  _globals['_BLOCKREF']._serialized_start=133
  _globals['_BLOCKREF']._serialized_end=185
  _globals['_ANYCHAINTXPATTERN']._serialized_start=187
  _globals['_ANYCHAINTXPATTERN']._serialized_end=279
  _globals['_TXPREDICATE']._serialized_start=282
  _globals['_TXPREDICATE']._serialized_end=531
  _globals['_WATCHTXREQUEST']._serialized_start=534
  _globals['_WATCHTXREQUEST']._serialized_end=738
  _globals['_ANYCHAINTX']._serialized_start=740
  _globals['_ANYCHAINTX']._serialized_end=818
  _globals['_WATCHTXRESPONSE']._serialized_start=821
  _globals['_WATCHTXRESPONSE']._serialized_end=964
  _globals['_WATCHSERVICE']._serialized_start=966
  _globals['_WATCHSERVICE']._serialized_end=1072
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from utxorpc_spec.utxorpc.v1alpha.query import query_pb2 as utxorpc_dot_v1alpha_dot_query_dot_query__pb2


class QueryServiceStub(object):
    """Service definition for querying the state of the chain.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReadParams = channel.unary_unary(
                '/utxorpc.v1alpha.query.QueryService/ReadParams',
                request_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadParamsRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadParamsResponse.FromString,
                _registered_method=True)
        self.ReadUtxos = channel.unary_unary(
                '/utxorpc.v1alpha.query.QueryService/ReadUtxos',
                request_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadUtxosRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadUtxosResponse.FromString,
                _registered_method=True)
        self.SearchUtxos = channel.unary_unary(
                '/utxorpc.v1alpha.query.QueryService/SearchUtxos',
                request_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.SearchUtxosRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.SearchUtxosResponse.FromString,
                _registered_method=True)
        self.ReadData = channel.unary_unary(
                '/utxorpc.v1alpha.query.QueryService/ReadData',
                request_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadDataRequest.SerializeToString,
                response_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadDataResponse.FromString,
                _registered_method=True)


class QueryServiceServicer(object):
    """Service definition for querying the state of the chain.
    """

    def ReadParams(self, request, context):
        """Get overall chain state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadUtxos(self, request, context):
        """Read specific UTxOs by reference.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchUtxos(self, request, context):
        """Search for UTxO based on a pattern.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadData(self, request, context):
        """Read specific datum by hash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReadParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadParams,
                    request_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadParamsRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadParamsResponse.SerializeToString,
            ),
            'ReadUtxos': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadUtxos,
                    request_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadUtxosRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadUtxosResponse.SerializeToString,
            ),
            'SearchUtxos': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchUtxos,
                    request_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.SearchUtxosRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.SearchUtxosResponse.SerializeToString,
            ),
            'ReadData': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadData,
                    request_deserializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadDataRequest.FromString,
                    response_serializer=utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadDataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'utxorpc.v1alpha.query.QueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('utxorpc.v1alpha.query.QueryService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class QueryService(object):
    """Service definition for querying the state of the chain.
    """

    @staticmethod
    def ReadParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.query.QueryService/ReadParams',
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadParamsRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReadUtxos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.query.QueryService/ReadUtxos',
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadUtxosRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadUtxosResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchUtxos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.query.QueryService/SearchUtxos',
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.SearchUtxosRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.SearchUtxosResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReadData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/utxorpc.v1alpha.query.QueryService/ReadData',
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadDataRequest.SerializeToString,
            utxorpc_dot_v1alpha_dot_query_dot_query__pb2.ReadDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/query/query.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/query/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!utxorpc/v1alpha/query/query.proto\x12\x15utxorpc.v1alpha.query\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"4\n\nChainPoint\x12\x12\n\x04slot\x18\x01 \x01(\x04R\x04slot\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"2\n\x06TxoRef\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\"N\n\x11ReadParamsRequest\x12\x39\n\nfield_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"X\n\x0e\x41nyChainParams\x12<\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.PParamsH\x00R\x07\x63\x61rdanoB\x08\n\x06params\"\x95\x01\n\x12ReadParamsResponse\x12=\n\x06values\x18\x01 \x01(\x0b\x32%.utxorpc.v1alpha.query.AnyChainParamsR\x06values\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip\"f\n\x0e\x41nyUtxoPattern\x12\x44\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.TxOutputPatternH\x00R\x07\x63\x61rdanoB\x0e\n\x0cutxo_pattern\"\xfe\x01\n\rUtxoPredicate\x12;\n\x05match\x18\x01 \x01(\x0b\x32%.utxorpc.v1alpha.query.AnyUtxoPatternR\x05match\x12\x36\n\x03not\x18\x02 \x03(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\x03not\x12;\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\x05\x61llOf\x12;\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\x05\x61nyOf\"\xb7\x01\n\x0b\x41nyUtxoData\x12!\n\x0cnative_bytes\x18\x01 \x01(\x0cR\x0bnativeBytes\x12\x36\n\x07txo_ref\x18\x02 \x01(\x0b\x32\x1d.utxorpc.v1alpha.query.TxoRefR\x06txoRef\x12=\n\x07\x63\x61rdano\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputH\x00R\x07\x63\x61rdanoB\x0e\n\x0cparsed_state\"\x80\x01\n\x10ReadUtxosRequest\x12\x31\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.utxorpc.v1alpha.query.TxoRefR\x04keys\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x8f\x01\n\x11ReadUtxosResponse\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.query.AnyUtxoDataR\x05items\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip\"\x93\x01\n\x12SearchUtxosRequest\x12\x42\n\tpredicate\x18\x01 \x01(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\tpredicate\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x91\x01\n\x13SearchUtxosResponse\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.query.AnyUtxoDataR\x05items\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip\"`\n\x0fReadDataRequest\x12\x12\n\x04keys\x18\x01 \x03(\x0cR\x04keys\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x95\x01\n\rAnyChainDatum\x12!\n\x0cnative_bytes\x18\x01 \x01(\x0cR\x0bnativeBytes\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12?\n\x07\x63\x61rdano\x18\x03 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataH\x00R\x07\x63\x61rdanoB\x0e\n\x0cparsed_state\"\x92\x01\n\x10ReadDataResponse\x12<\n\x06values\x18\x01 \x03(\x0b\x32$.utxorpc.v1alpha.query.AnyChainDatumR\x06values\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip2\x94\x03\n\x0cQueryService\x12\x61\n\nReadParams\x12(.utxorpc.v1alpha.query.ReadParamsRequest\x1a).utxorpc.v1alpha.query.ReadParamsResponse\x12^\n\tReadUtxos\x12\'.utxorpc.v1alpha.query.ReadUtxosRequest\x1a(.utxorpc.v1alpha.query.ReadUtxosResponse\x12\x64\n\x0bSearchUtxos\x12).utxorpc.v1alpha.query.SearchUtxosRequest\x1a*.utxorpc.v1alpha.query.SearchUtxosResponse\x12[\n\x08ReadData\x12&.utxorpc.v1alpha.query.ReadDataRequest\x1a\'.utxorpc.v1alpha.query.ReadDataResponseB\xd2\x01\n\x19\x63om.utxorpc.v1alpha.queryB\nQueryProtoP\x01Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/query\xa2\x02\x03UVQ\xaa\x02\x15Utxorpc.V1alpha.Query\xca\x02\x15Utxorpc\\V1alpha\\Query\xe2\x02!Utxorpc\\V1alpha\\Query\\GPBMetadata\xea\x02\x17Utxorpc::V1alpha::Queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.query.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.utxorpc.v1alpha.queryB\nQueryProtoP\001Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/query\242\002\003UVQ\252\002\025Utxorpc.V1alpha.Query\312\002\025Utxorpc\\V1alpha\\Query\342\002!Utxorpc\\V1alpha\\Query\\GPBMetadata\352\002\027Utxorpc::V1alpha::Query'
  _globals['_CHAINPOINT']._serialized_start=133
  _globals['_CHAINPOINT']._serialized_end=185
  _globals['_TXOREF']._serialized_start=187
  _globals['_TXOREF']._serialized_end=237
  _globals['_READPARAMSREQUEST']._serialized_start=239
  _globals['_READPARAMSREQUEST']._serialized_end=317
  _globals['_ANYCHAINPARAMS']._serialized_start=319
  _globals['_ANYCHAINPARAMS']._serialized_end=407
  _globals['_READPARAMSRESPONSE']._serialized_start=410
  _globals['_READPARAMSRESPONSE']._serialized_end=559
  _globals['_ANYUTXOPATTERN']._serialized_start=561
  _globals['_ANYUTXOPATTERN']._serialized_end=663
  _globals['_UTXOPREDICATE']._serialized_start=666
  _globals['_UTXOPREDICATE']._serialized_end=920
  _globals['_ANYUTXODATA']._serialized_start=923
  _globals['_ANYUTXODATA']._serialized_end=1106
  _globals['_READUTXOSREQUEST']._serialized_start=1109
  _globals['_READUTXOSREQUEST']._serialized_end=1237
  _globals['_READUTXOSRESPONSE']._serialized_start=1240
  _globals['_READUTXOSRESPONSE']._serialized_end=1383
  _globals['_SEARCHUTXOSREQUEST']._serialized_start=1386
  _globals['_SEARCHUTXOSREQUEST']._serialized_end=1533
  _globals['_SEARCHUTXOSRESPONSE']._serialized_start=1536
  _globals['_SEARCHUTXOSRESPONSE']._serialized_end=1681
  _globals['_READDATAREQUEST']._serialized_start=1683
  _globals['_READDATAREQUEST']._serialized_end=1779
  _globals['_ANYCHAINDATUM']._serialized_start=1782
  _globals['_ANYCHAINDATUM']._serialized_end=1931
  _globals['_READDATARESPONSE']._serialized_start=1934
  _globals['_READDATARESPONSE']._serialized_end=2080
  _globals['_QUERYSERVICE']._serialized_start=2083
  _globals['_QUERYSERVICE']._serialized_end=2487
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/sync/sync.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/sync/sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1futxorpc/v1alpha/sync/sync.proto\x12\x14utxorpc.v1alpha.sync\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"4\n\x08\x42lockRef\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"w\n\rAnyChainBlock\x12!\n\x0cnative_bytes\x18\x01 \x01(\x0cR\x0bnativeBytes\x12:\n\x07\x63\x61rdano\x18\x02 \x01(\x0b\x32\x1e.utxorpc.v1alpha.cardano.BlockH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\x80\x01\n\x11\x46\x65tchBlockRequest\x12\x30\n\x03ref\x18\x01 \x03(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\x03ref\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"O\n\x12\x46\x65tchBlockResponse\x12\x39\n\x05\x62lock\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockR\x05\x62lock\"\xad\x01\n\x12\x44umpHistoryRequest\x12?\n\x0bstart_token\x18\x02 \x01(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\nstartToken\x12\x1b\n\tmax_items\x18\x03 \x01(\rR\x08maxItems\x12\x39\n\nfield_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x8f\x01\n\x13\x44umpHistoryResponse\x12\x39\n\x05\x62lock\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockR\x05\x62lock\x12=\n\nnext_token\x18\x02 \x01(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\tnextToken\"\x8b\x01\n\x10\x46ollowTipRequest\x12<\n\tintersect\x18\x01 \x03(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\tintersect\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\xcd\x01\n\x11\x46ollowTipResponse\x12;\n\x05\x61pply\x18\x01 \x01(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockH\x00R\x05\x61pply\x12\x39\n\x04undo\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockH\x00R\x04undo\x12\x36\n\x05reset\x18\x03 \x01(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefH\x00R\x05resetB\x08\n\x06\x61\x63tion2\xb2\x02\n\x0bSyncService\x12_\n\nFetchBlock\x12\'.utxorpc.v1alpha.sync.FetchBlockRequest\x1a(.utxorpc.v1alpha.sync.FetchBlockResponse\x12\x62\n\x0b\x44umpHistory\x12(.utxorpc.v1alpha.sync.DumpHistoryRequest\x1a).utxorpc.v1alpha.sync.DumpHistoryResponse\x12^\n\tFollowTip\x12&.utxorpc.v1alpha.sync.FollowTipRequest\x1a\'.utxorpc.v1alpha.sync.FollowTipResponse0\x01\x42\xcb\x01\n\x18\x63om.utxorpc.v1alpha.syncB\tSyncProtoP\x01Z2github.com/utxorpc/go-codegen/utxorpc/v1alpha/sync\xa2\x02\x03UVS\xaa\x02\x14Utxorpc.V1alpha.Sync\xca\x02\x14Utxorpc\\V1alpha\\Sync\xe2\x02 Utxorpc\\V1alpha\\Sync\\GPBMetadata\xea\x02\x16Utxorpc::V1alpha::Syncb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.sync.sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.utxorpc.v1alpha.syncB\tSyncProtoP\001Z2github.com/utxorpc/go-codegen/utxorpc/v1alpha/sync\242\002\003UVS\252\002\024Utxorpc.V1alpha.Sync\312\002\024Utxorpc\\V1alpha\\Sync\342\002 Utxorpc\\V1alpha\\Sync\\GPBMetadata\352\002\026Utxorpc::V1alpha::Sync'
  _globals['_BLOCKREF']._serialized_start=130
  _globals['_BLOCKREF']._serialized_end=182
  _globals['_ANYCHAINBLOCK']._serialized_start=184
  _globals['_ANYCHAINBLOCK']._serialized_end=303
  _globals['_FETCHBLOCKREQUEST']._serialized_start=306
  _globals['_FETCHBLOCKREQUEST']._serialized_end=434
  _globals['_FETCHBLOCKRESPONSE']._serialized_start=436
  _globals['_FETCHBLOCKRESPONSE']._serialized_end=515
  _globals['_DUMPHISTORYREQUEST']._serialized_start=518
  _globals['_DUMPHISTORYREQUEST']._serialized_end=691
  _globals['_DUMPHISTORYRESPONSE']._serialized_start=694
  _globals['_DUMPHISTORYRESPONSE']._serialized_end=837
  _globals['_FOLLOWTIPREQUEST']._serialized_start=840
  _globals['_FOLLOWTIPREQUEST']._serialized_end=979
  _globals['_FOLLOWTIPRESPONSE']._serialized_start=982
  _globals['_FOLLOWTIPRESPONSE']._serialized_end=1187
  _globals['_SYNCSERVICE']._serialized_start=1190
  _globals['_SYNCSERVICE']._serialized_end=1496
# @@protoc_insertion_point(module_scope)



from google.protobuf import field_mask_pb2 as _field_mask_pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as _cardano_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ChainPoint(_message.Message):
    __slots__ = ("slot", "hash")
    SLOT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    slot: int
    hash: bytes
    def __init__(self, slot: _Optional[int] = ..., hash: _Optional[bytes] = ...) -> None: ...

class TxoRef(_message.Message):
    __slots__ = ("hash", "index")
    HASH_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    index: int
    def __init__(self, hash: _Optional[bytes] = ..., index: _Optional[int] = ...) -> None: ...

class ReadParamsRequest(_message.Message):
    __slots__ = ("field_mask",)
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class AnyChainParams(_message.Message):
    __slots__ = ("cardano",)
    CARDANO_FIELD_NUMBER: _ClassVar[int]
    cardano: _cardano_pb2.PParams
    def __init__(self, cardano: _Optional[_Union[_cardano_pb2.PParams, _Mapping]] = ...) -> None: ...

class ReadParamsResponse(_message.Message):
    __slots__ = ("values", "ledger_tip")
    VALUES_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIP_FIELD_NUMBER: _ClassVar[int]
    values: AnyChainParams
    ledger_tip: ChainPoint
    def __init__(self, values: _Optional[_Union[AnyChainParams, _Mapping]] = ..., ledger_tip: _Optional[_Union[ChainPoint, _Mapping]] = ...) -> None: ...

class AnyUtxoPattern(_message.Message):
    __slots__ = ("cardano",)
    CARDANO_FIELD_NUMBER: _ClassVar[int]
    cardano: _cardano_pb2.TxOutputPattern
    def __init__(self, cardano: _Optional[_Union[_cardano_pb2.TxOutputPattern, _Mapping]] = ...) -> None: ...

class UtxoPredicate(_message.Message):
    __slots__ = ("match", "all_of", "any_of")
    MATCH_FIELD_NUMBER: _ClassVar[int]
    NOT_FIELD_NUMBER: _ClassVar[int]
    ALL_OF_FIELD_NUMBER: _ClassVar[int]
    ANY_OF_FIELD_NUMBER: _ClassVar[int]
    match: AnyUtxoPattern
    all_of: _containers.RepeatedCompositeFieldContainer[UtxoPredicate]
    any_of: _containers.RepeatedCompositeFieldContainer[UtxoPredicate]
    def __init__(self, match: _Optional[_Union[AnyUtxoPattern, _Mapping]] = ..., all_of: _Optional[_Iterable[_Union[UtxoPredicate, _Mapping]]] = ..., any_of: _Optional[_Iterable[_Union[UtxoPredicate, _Mapping]]] = ..., **kwargs) -> None: ...

class AnyUtxoData(_message.Message):
    __slots__ = ("native_bytes", "txo_ref", "cardano")
    NATIVE_BYTES_FIELD_NUMBER: _ClassVar[int]
    TXO_REF_FIELD_NUMBER: _ClassVar[int]
    CARDANO_FIELD_NUMBER: _ClassVar[int]
    native_bytes: bytes
    txo_ref: TxoRef
    cardano: _cardano_pb2.TxOutput
    def __init__(self, native_bytes: _Optional[bytes] = ..., txo_ref: _Optional[_Union[TxoRef, _Mapping]] = ..., cardano: _Optional[_Union[_cardano_pb2.TxOutput, _Mapping]] = ...) -> None: ...

class ReadUtxosRequest(_message.Message):
    __slots__ = ("keys", "field_mask")
    KEYS_FIELD_NUMBER: _ClassVar[int]
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedCompositeFieldContainer[TxoRef]
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, keys: _Optional[_Iterable[_Union[TxoRef, _Mapping]]] = ..., field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class ReadUtxosResponse(_message.Message):
    __slots__ = ("items", "ledger_tip")
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIP_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[AnyUtxoData]
    ledger_tip: ChainPoint
    def __init__(self, items: _Optional[_Iterable[_Union[AnyUtxoData, _Mapping]]] = ..., ledger_tip: _Optional[_Union[ChainPoint, _Mapping]] = ...) -> None: ...

class SearchUtxosRequest(_message.Message):
    __slots__ = ("predicate", "field_mask")
    PREDICATE_FIELD_NUMBER: _ClassVar[int]
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    predicate: UtxoPredicate
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, predicate: _Optional[_Union[UtxoPredicate, _Mapping]] = ..., field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class SearchUtxosResponse(_message.Message):
    __slots__ = ("items", "ledger_tip")
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIP_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[AnyUtxoData]
    ledger_tip: ChainPoint
    def __init__(self, items: _Optional[_Iterable[_Union[AnyUtxoData, _Mapping]]] = ..., ledger_tip: _Optional[_Union[ChainPoint, _Mapping]] = ...) -> None: ...

class ReadDataRequest(_message.Message):
    __slots__ = ("keys", "field_mask")
    KEYS_FIELD_NUMBER: _ClassVar[int]
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedScalarFieldContainer[bytes]
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, keys: _Optional[_Iterable[bytes]] = ..., field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class AnyChainDatum(_message.Message):
    __slots__ = ("native_bytes", "key", "cardano")
    NATIVE_BYTES_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    CARDANO_FIELD_NUMBER: _ClassVar[int]
    native_bytes: bytes
    key: bytes
    cardano: _cardano_pb2.PlutusData
    def __init__(self, native_bytes: _Optional[bytes] = ..., key: _Optional[bytes] = ..., cardano: _Optional[_Union[_cardano_pb2.PlutusData, _Mapping]] = ...) -> None: ...

class ReadDataResponse(_message.Message):
    __slots__ = ("values", "ledger_tip")
    VALUES_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIP_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[AnyChainDatum]
    ledger_tip: ChainPoint
    def __init__(self, values: _Optional[_Iterable[_Union[AnyChainDatum, _Mapping]]] = ..., ledger_tip: _Optional[_Union[ChainPoint, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/cardano/cardano.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/cardano/cardano.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%utxorpc/v1alpha/cardano/cardano.proto\x12\x17utxorpc.v1alpha.cardano\"\x8d\x01\n\x08Redeemer\x12\x42\n\x07purpose\x18\x01 \x01(\x0e\x32(.utxorpc.v1alpha.cardano.RedeemerPurposeR\x07purpose\x12=\n\x07payload\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x07payload\"\xc4\x01\n\x07TxInput\x12\x17\n\x07tx_hash\x18\x01 \x01(\x0cR\x06txHash\x12!\n\x0coutput_index\x18\x02 \x01(\rR\x0boutputIndex\x12>\n\tas_output\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputR\x08\x61sOutput\x12=\n\x08redeemer\x18\x04 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemer\"\xe4\x01\n\x08TxOutput\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0cR\x07\x61\x64\x64ress\x12\x12\n\x04\x63oin\x18\x02 \x01(\x04R\x04\x63oin\x12;\n\x06\x61ssets\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.MultiassetR\x06\x61ssets\x12\x34\n\x05\x64\x61tum\x18\x04 \x01(\x0b\x32\x1e.utxorpc.v1alpha.cardano.DatumR\x05\x64\x61tum\x12\x37\n\x06script\x18\x05 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ScriptR\x06script\"\x7f\n\x05\x44\x61tum\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12=\n\x07payload\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x07payload\x12#\n\roriginal_cbor\x18\x03 \x01(\x0cR\x0coriginalCbor\"Y\n\x05\x41sset\x12\x12\n\x04name\x18\x01 \x01(\x0cR\x04name\x12\x1f\n\x0boutput_coin\x18\x02 \x01(\x04R\noutputCoin\x12\x1b\n\tmint_coin\x18\x03 \x01(\x03R\x08mintCoin\"\xa0\x01\n\nMultiasset\x12\x1b\n\tpolicy_id\x18\x01 \x01(\x0cR\x08policyId\x12\x36\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x1e.utxorpc.v1alpha.cardano.AssetR\x06\x61ssets\x12=\n\x08redeemer\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemer\"4\n\nTxValidity\x12\x14\n\x05start\x18\x01 \x01(\x04R\x05start\x12\x10\n\x03ttl\x18\x02 \x01(\x04R\x03ttl\"\xc9\x01\n\nCollateral\x12@\n\ncollateral\x18\x01 \x03(\x0b\x32 .utxorpc.v1alpha.cardano.TxInputR\ncollateral\x12N\n\x11\x63ollateral_return\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputR\x10\x63ollateralReturn\x12)\n\x10total_collateral\x18\x03 \x01(\x04R\x0ftotalCollateral\"\x86\x01\n\nWithdrawal\x12%\n\x0ereward_account\x18\x01 \x01(\x0cR\rrewardAccount\x12\x12\n\x04\x63oin\x18\x02 \x01(\x04R\x04\x63oin\x12=\n\x08redeemer\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemer\"\xd7\x01\n\nWitnessSet\x12\x46\n\x0bvkeywitness\x18\x01 \x03(\x0b\x32$.utxorpc.v1alpha.cardano.VKeyWitnessR\x0bvkeywitness\x12\x37\n\x06script\x18\x02 \x03(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ScriptR\x06script\x12H\n\rplutus_datums\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x0cplutusDatums\"\x83\x01\n\x07\x41uxData\x12=\n\x08metadata\x18\x01 \x03(\x0b\x32!.utxorpc.v1alpha.cardano.MetadataR\x08metadata\x12\x39\n\x07scripts\x18\x02 \x03(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ScriptR\x07scripts\"\xe1\x05\n\x02Tx\x12\x38\n\x06inputs\x18\x01 \x03(\x0b\x32 .utxorpc.v1alpha.cardano.TxInputR\x06inputs\x12;\n\x07outputs\x18\x02 \x03(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputR\x07outputs\x12H\n\x0c\x63\x65rtificates\x18\x03 \x03(\x0b\x32$.utxorpc.v1alpha.cardano.CertificateR\x0c\x63\x65rtificates\x12\x45\n\x0bwithdrawals\x18\x04 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.WithdrawalR\x0bwithdrawals\x12\x37\n\x04mint\x18\x05 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.MultiassetR\x04mint\x12K\n\x10reference_inputs\x18\x06 \x03(\x0b\x32 .utxorpc.v1alpha.cardano.TxInputR\x0freferenceInputs\x12\x41\n\twitnesses\x18\x07 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.WitnessSetR\twitnesses\x12\x43\n\ncollateral\x18\x08 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.CollateralR\ncollateral\x12\x10\n\x03\x66\x65\x65\x18\t \x01(\x04R\x03\x66\x65\x65\x12?\n\x08validity\x18\n \x01(\x0b\x32#.utxorpc.v1alpha.cardano.TxValidityR\x08validity\x12\x1e\n\nsuccessful\x18\x0b \x01(\x08R\nsuccessful\x12>\n\tauxiliary\x18\x0c \x01(\x0b\x32 .utxorpc.v1alpha.cardano.AuxDataR\tauxiliary\x12\x12\n\x04hash\x18\r \x01(\x0cR\x04hash\"M\n\x0b\x42lockHeader\x12\x12\n\x04slot\x18\x01 \x01(\x04R\x04slot\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x03 \x01(\x04R\x06height\"8\n\tBlockBody\x12+\n\x02tx\x18\x01 \x03(\x0b\x32\x1b.utxorpc.v1alpha.cardano.TxR\x02tx\"}\n\x05\x42lock\x12<\n\x06header\x18\x01 \x01(\x0b\x32$.utxorpc.v1alpha.cardano.BlockHeaderR\x06header\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.BlockBodyR\x04\x62ody\"?\n\x0bVKeyWitness\x12\x12\n\x04vkey\x18\x01 \x01(\x0cR\x04vkey\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\"\x80\x03\n\x0cNativeScript\x12%\n\rscript_pubkey\x18\x01 \x01(\x0cH\x00R\x0cscriptPubkey\x12J\n\nscript_all\x18\x02 \x01(\x0b\x32).utxorpc.v1alpha.cardano.NativeScriptListH\x00R\tscriptAll\x12J\n\nscript_any\x18\x03 \x01(\x0b\x32).utxorpc.v1alpha.cardano.NativeScriptListH\x00R\tscriptAny\x12H\n\rscript_n_of_k\x18\x04 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.ScriptNOfKH\x00R\nscriptNOfK\x12\'\n\x0einvalid_before\x18\x05 \x01(\x04H\x00R\rinvalidBefore\x12-\n\x11invalid_hereafter\x18\x06 \x01(\x04H\x00R\x10invalidHereafterB\x0f\n\rnative_script\"O\n\x10NativeScriptList\x12;\n\x05items\x18\x01 \x03(\x0b\x32%.utxorpc.v1alpha.cardano.NativeScriptR\x05items\"[\n\nScriptNOfK\x12\x0c\n\x01k\x18\x01 \x01(\rR\x01k\x12?\n\x07scripts\x18\x02 \x03(\x0b\x32%.utxorpc.v1alpha.cardano.NativeScriptR\x07scripts\"\x80\x01\n\x06\x43onstr\x12\x10\n\x03tag\x18\x01 \x01(\rR\x03tag\x12\'\n\x0f\x61ny_constructor\x18\x02 \x01(\x04R\x0e\x61nyConstructor\x12;\n\x06\x66ields\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x06\x66ields\"c\n\x06\x42igInt\x12\x12\n\x03int\x18\x01 \x01(\x03H\x00R\x03int\x12\x1c\n\tbig_u_int\x18\x02 \x01(\x0cH\x00R\x07\x62igUInt\x12\x1c\n\tbig_n_int\x18\x03 \x01(\x0cH\x00R\x07\x62igNIntB\t\n\x07\x62ig_int\"\x82\x01\n\x0ePlutusDataPair\x12\x35\n\x03key\x18\x01 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x03key\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x05value\"\xb7\x02\n\nPlutusData\x12\x39\n\x06\x63onstr\x18\x02 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ConstrH\x00R\x06\x63onstr\x12:\n\x03map\x18\x03 \x01(\x0b\x32&.utxorpc.v1alpha.cardano.PlutusDataMapH\x00R\x03map\x12:\n\x07\x62ig_int\x18\x04 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.BigIntH\x00R\x06\x62igInt\x12%\n\rbounded_bytes\x18\x05 \x01(\x0cH\x00R\x0c\x62oundedBytes\x12@\n\x05\x61rray\x18\x06 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.PlutusDataArrayH\x00R\x05\x61rrayB\r\n\x0bplutus_data\"N\n\rPlutusDataMap\x12=\n\x05pairs\x18\x01 \x03(\x0b\x32\'.utxorpc.v1alpha.cardano.PlutusDataPairR\x05pairs\"L\n\x0fPlutusDataArray\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x05items\"\x91\x01\n\x06Script\x12?\n\x06native\x18\x01 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.NativeScriptH\x00R\x06native\x12\x1d\n\tplutus_v1\x18\x02 \x01(\x0cH\x00R\x08plutusV1\x12\x1d\n\tplutus_v2\x18\x03 \x01(\x0cH\x00R\x08plutusV2B\x08\n\x06script\"\xd6\x01\n\tMetadatum\x12\x12\n\x03int\x18\x01 \x01(\x03H\x00R\x03int\x12\x16\n\x05\x62ytes\x18\x02 \x01(\x0cH\x00R\x05\x62ytes\x12\x14\n\x04text\x18\x03 \x01(\tH\x00R\x04text\x12?\n\x05\x61rray\x18\x04 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.MetadatumArrayH\x00R\x05\x61rray\x12\x39\n\x03map\x18\x05 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.MetadatumMapH\x00R\x03mapB\x0b\n\tmetadatum\"J\n\x0eMetadatumArray\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x05items\"L\n\x0cMetadatumMap\x12<\n\x05pairs\x18\x01 \x03(\x0b\x32&.utxorpc.v1alpha.cardano.MetadatumPairR\x05pairs\"\x7f\n\rMetadatumPair\x12\x34\n\x03key\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x03key\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x05value\"Z\n\x08Metadata\x12\x14\n\x05label\x18\x01 \x01(\x04R\x05label\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x05value\"n\n\x0fStakeCredential\x12$\n\raddr_key_hash\x18\x01 \x01(\x0cH\x00R\x0b\x61\x64\x64rKeyHash\x12!\n\x0bscript_hash\x18\x02 \x01(\x0cH\x00R\nscriptHashB\x12\n\x10stake_credential\"P\n\x0eRationalNumber\x12\x1c\n\tnumerator\x18\x01 \x01(\x05R\tnumerator\x12 \n\x0b\x64\x65nominator\x18\x02 \x01(\rR\x0b\x64\x65nominator\"`\n\x05Relay\x12\x13\n\x05ip_v4\x18\x01 \x01(\x0cR\x04ipV4\x12\x13\n\x05ip_v6\x18\x02 \x01(\x0cR\x04ipV6\x12\x19\n\x08\x64ns_name\x18\x03 \x01(\tR\x07\x64nsName\x12\x12\n\x04port\x18\x04 \x01(\rR\x04port\"4\n\x0cPoolMetadata\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"\xd0\x05\n\x0b\x43\x65rtificate\x12Y\n\x12stake_registration\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialH\x00R\x11stakeRegistration\x12]\n\x14stake_deregistration\x18\x02 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialH\x00R\x13stakeDeregistration\x12Y\n\x10stake_delegation\x18\x03 \x01(\x0b\x32,.utxorpc.v1alpha.cardano.StakeDelegationCertH\x00R\x0fstakeDelegation\x12\\\n\x11pool_registration\x18\x04 \x01(\x0b\x32-.utxorpc.v1alpha.cardano.PoolRegistrationCertH\x00R\x10poolRegistration\x12V\n\x0fpool_retirement\x18\x05 \x01(\x0b\x32+.utxorpc.v1alpha.cardano.PoolRetirementCertH\x00R\x0epoolRetirement\x12i\n\x16genesis_key_delegation\x18\x06 \x01(\x0b\x32\x31.utxorpc.v1alpha.cardano.GenesisKeyDelegationCertH\x00R\x14genesisKeyDelegation\x12=\n\x08mir_cert\x18\x07 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.MirCertH\x00R\x07mirCert\x12=\n\x08redeemer\x18\x64 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemerB\r\n\x0b\x63\x65rtificate\"\x8d\x01\n\x13StakeDelegationCert\x12S\n\x10stake_credential\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialR\x0fstakeCredential\x12!\n\x0cpool_keyhash\x18\x02 \x01(\x0cR\x0bpoolKeyhash\"\x8c\x03\n\x14PoolRegistrationCert\x12\x1a\n\x08operator\x18\x01 \x01(\x0cR\x08operator\x12\x1f\n\x0bvrf_keyhash\x18\x02 \x01(\x0cR\nvrfKeyhash\x12\x16\n\x06pledge\x18\x03 \x01(\x04R\x06pledge\x12\x12\n\x04\x63ost\x18\x04 \x01(\x04R\x04\x63ost\x12?\n\x06margin\x18\x05 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x06margin\x12%\n\x0ereward_account\x18\x06 \x01(\x0cR\rrewardAccount\x12\x1f\n\x0bpool_owners\x18\x07 \x03(\x0cR\npoolOwners\x12\x36\n\x06relays\x18\x08 \x03(\x0b\x32\x1e.utxorpc.v1alpha.cardano.RelayR\x06relays\x12J\n\rpool_metadata\x18\t \x01(\x0b\x32%.utxorpc.v1alpha.cardano.PoolMetadataR\x0cpoolMetadata\"M\n\x12PoolRetirementCert\x12!\n\x0cpool_keyhash\x18\x01 \x01(\x0cR\x0bpoolKeyhash\x12\x14\n\x05\x65poch\x18\x02 \x01(\x04R\x05\x65poch\"\x92\x01\n\x18GenesisKeyDelegationCert\x12!\n\x0cgenesis_hash\x18\x01 \x01(\x0cR\x0bgenesisHash\x12\x32\n\x15genesis_delegate_hash\x18\x02 \x01(\x0cR\x13genesisDelegateHash\x12\x1f\n\x0bvrf_keyhash\x18\x03 \x01(\x0cR\nvrfKeyhash\"\x7f\n\tMirTarget\x12S\n\x10stake_credential\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialR\x0fstakeCredential\x12\x1d\n\ndelta_coin\x18\x02 \x01(\x03R\tdeltaCoin\"\x92\x01\n\x07MirCert\x12\x36\n\x04\x66rom\x18\x01 \x01(\x0e\x32\".utxorpc.v1alpha.cardano.MirSourceR\x04\x66rom\x12\x32\n\x02to\x18\x02 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.MirTargetR\x02to\x12\x1b\n\tother_pot\x18\x03 \x01(\x04R\x08otherPot\"\x81\x01\n\x0e\x41\x64\x64ressPattern\x12#\n\rexact_address\x18\x01 \x01(\x0cR\x0c\x65xactAddress\x12!\n\x0cpayment_part\x18\x02 \x01(\x0cR\x0bpaymentPart\x12\'\n\x0f\x64\x65legation_part\x18\x03 \x01(\x0cR\x0e\x64\x65legationPart\"J\n\x0c\x41ssetPattern\x12\x1b\n\tpolicy_id\x18\x01 \x01(\x0cR\x08policyId\x12\x1d\n\nasset_name\x18\x02 \x01(\x0cR\tassetName\"\x91\x01\n\x0fTxOutputPattern\x12\x41\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.AddressPatternR\x07\x61\x64\x64ress\x12;\n\x05\x61sset\x18\x02 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.AssetPatternR\x05\x61sset\"\xf1\x02\n\tTxPattern\x12\x44\n\x08\x63onsumes\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.TxOutputPatternR\x08\x63onsumes\x12\x44\n\x08produces\x18\x02 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.TxOutputPatternR\x08produces\x12H\n\x0bhas_address\x18\x03 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.AddressPatternR\nhasAddress\x12\x46\n\x0bmoves_asset\x18\x04 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.AssetPatternR\nmovesAsset\x12\x46\n\x0bmints_asset\x18\x05 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.AssetPatternR\nmintsAsset\"7\n\x07\x45xUnits\x12\x14\n\x05steps\x18\x01 \x01(\x04R\x05steps\x12\x16\n\x06memory\x18\x02 \x01(\x04R\x06memory\"\x8a\x01\n\x08\x45xPrices\x12=\n\x05steps\x18\x01 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x05steps\x12?\n\x06memory\x18\x02 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x06memory\"=\n\x0fProtocolVersion\x12\x14\n\x05major\x18\x01 \x01(\rR\x05major\x12\x14\n\x05minor\x18\x02 \x01(\rR\x05minor\"#\n\tCostModel\x12\x16\n\x06values\x18\x01 \x03(\x03R\x06values\"\x8e\x01\n\nCostModels\x12?\n\tplutus_v1\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.CostModelR\x08plutusV1\x12?\n\tplutus_v2\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.CostModelR\x08plutusV2\"\xb6\n\n\x07PParams\x12-\n\x13\x63oins_per_utxo_byte\x18\x01 \x01(\x04R\x10\x63oinsPerUtxoByte\x12\x1e\n\x0bmax_tx_size\x18\x02 \x01(\x04R\tmaxTxSize\x12.\n\x13min_fee_coefficient\x18\x03 \x01(\x04R\x11minFeeCoefficient\x12(\n\x10min_fee_constant\x18\x04 \x01(\x04R\x0eminFeeConstant\x12-\n\x13max_block_body_size\x18\x05 \x01(\x04R\x10maxBlockBodySize\x12\x31\n\x15max_block_header_size\x18\x06 \x01(\x04R\x12maxBlockHeaderSize\x12*\n\x11stake_key_deposit\x18\x07 \x01(\x04R\x0fstakeKeyDeposit\x12!\n\x0cpool_deposit\x18\x08 \x01(\x04R\x0bpoolDeposit\x12=\n\x1bpool_retirement_epoch_bound\x18\t \x01(\x04R\x18poolRetirementEpochBound\x12\x35\n\x17\x64\x65sired_number_of_pools\x18\n \x01(\x04R\x14\x64\x65siredNumberOfPools\x12N\n\x0epool_influence\x18\x0b \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\rpoolInfluence\x12V\n\x12monetary_expansion\x18\x0c \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x11monetaryExpansion\x12V\n\x12treasury_expansion\x18\r \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x11treasuryExpansion\x12\"\n\rmin_pool_cost\x18\x0e \x01(\x04R\x0bminPoolCost\x12S\n\x10protocol_version\x18\x0f \x01(\x0b\x32(.utxorpc.v1alpha.cardano.ProtocolVersionR\x0fprotocolVersion\x12$\n\x0emax_value_size\x18\x10 \x01(\x04R\x0cmaxValueSize\x12\x33\n\x15\x63ollateral_percentage\x18\x11 \x01(\x04R\x14\x63ollateralPercentage\x12\x32\n\x15max_collateral_inputs\x18\x12 \x01(\x04R\x13maxCollateralInputs\x12\x44\n\x0b\x63ost_models\x18\x13 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.CostModelsR\ncostModels\x12\x39\n\x06prices\x18\x14 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.ExPricesR\x06prices\x12n\n#max_execution_units_per_transaction\x18\x15 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.ExUnitsR\x1fmaxExecutionUnitsPerTransaction\x12\x62\n\x1dmax_execution_units_per_block\x18\x16 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.ExUnitsR\x19maxExecutionUnitsPerBlock\"\x1d\n\tEvalError\x12\x10\n\x03msg\x18\x01 \x01(\tR\x03msg\"\x1d\n\tEvalTrace\x12\x10\n\x03msg\x18\x01 \x01(\tR\x03msg\"\xcf\x01\n\x06TxEval\x12\x10\n\x03\x66\x65\x65\x18\x01 \x01(\x04R\x03\x66\x65\x65\x12;\n\x08\x65x_units\x18\x02 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.ExUnitsR\x07\x65xUnits\x12:\n\x06\x65rrors\x18\x03 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.EvalErrorR\x06\x65rrors\x12:\n\x06traces\x18\x04 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.EvalTraceR\x06traces*\xa2\x01\n\x0fRedeemerPurpose\x12 \n\x1cREDEEMER_PURPOSE_UNSPECIFIED\x10\x00\x12\x1a\n\x16REDEEMER_PURPOSE_SPEND\x10\x01\x12\x19\n\x15REDEEMER_PURPOSE_MINT\x10\x02\x12\x19\n\x15REDEEMER_PURPOSE_CERT\x10\x03\x12\x1b\n\x17REDEEMER_PURPOSE_REWARD\x10\x04*Y\n\tMirSource\x12\x1a\n\x16MIR_SOURCE_UNSPECIFIED\x10\x00\x12\x17\n\x13MIR_SOURCE_RESERVES\x10\x01\x12\x17\n\x13MIR_SOURCE_TREASURY\x10\x02\x42\xe0\x01\n\x1b\x63om.utxorpc.v1alpha.cardanoB\x0c\x43\x61rdanoProtoP\x01Z5github.com/utxorpc/go-codegen/utxorpc/v1alpha/cardano\xa2\x02\x03UVC\xaa\x02\x17Utxorpc.V1alpha.Cardano\xca\x02\x17Utxorpc\\V1alpha\\Cardano\xe2\x02#Utxorpc\\V1alpha\\Cardano\\GPBMetadata\xea\x02\x19Utxorpc::V1alpha::Cardanob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.cardano.cardano_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.utxorpc.v1alpha.cardanoB\014CardanoProtoP\001Z5github.com/utxorpc/go-codegen/utxorpc/v1alpha/cardano\242\002\003UVC\252\002\027Utxorpc.V1alpha.Cardano\312\002\027Utxorpc\\V1alpha\\Cardano\342\002#Utxorpc\\V1alpha\\Cardano\\GPBMetadata\352\002\031Utxorpc::V1alpha::Cardano'
  _globals['_REDEEMERPURPOSE']._serialized_start=9876
  _globals['_REDEEMERPURPOSE']._serialized_end=10038
  _globals['_MIRSOURCE']._serialized_start=10040
  _globals['_MIRSOURCE']._serialized_end=10129
  _globals['_REDEEMER']._serialized_start=67
  _globals['_REDEEMER']._serialized_end=208
  _globals['_TXINPUT']._serialized_start=211
  _globals['_TXINPUT']._serialized_end=407
  _globals['_TXOUTPUT']._serialized_start=410
  _globals['_TXOUTPUT']._serialized_end=638
  _globals['_DATUM']._serialized_start=640
  _globals['_DATUM']._serialized_end=767
  _globals['_ASSET']._serialized_start=769
  _globals['_ASSET']._serialized_end=858
  _globals['_MULTIASSET']._serialized_start=861
  _globals['_MULTIASSET']._serialized_end=1021
  _globals['_TXVALIDITY']._serialized_start=1023
  _globals['_TXVALIDITY']._serialized_end=1075
  _globals['_COLLATERAL']._serialized_start=1078
  _globals['_COLLATERAL']._serialized_end=1279
  _globals['_WITHDRAWAL']._serialized_start=1282
  _globals['_WITHDRAWAL']._serialized_end=1416
  _globals['_WITNESSSET']._serialized_start=1419
  _globals['_WITNESSSET']._serialized_end=1634
  _globals['_AUXDATA']._serialized_start=1637
  _globals['_AUXDATA']._serialized_end=1768
  _globals['_TX']._serialized_start=1771
  _globals['_TX']._serialized_end=2508
  _globals['_BLOCKHEADER']._serialized_start=2510
  _globals['_BLOCKHEADER']._serialized_end=2587
  _globals['_BLOCKBODY']._serialized_start=2589
  _globals['_BLOCKBODY']._serialized_end=2645
  _globals['_BLOCK']._serialized_start=2647
  _globals['_BLOCK']._serialized_end=2772
  _globals['_VKEYWITNESS']._serialized_start=2774
  _globals['_VKEYWITNESS']._serialized_end=2837
  _globals['_NATIVESCRIPT']._serialized_start=2840
  _globals['_NATIVESCRIPT']._serialized_end=3224
  _globals['_NATIVESCRIPTLIST']._serialized_start=3226
  _globals['_NATIVESCRIPTLIST']._serialized_end=3305
  _globals['_SCRIPTNOFK']._serialized_start=3307
  _globals['_SCRIPTNOFK']._serialized_end=3398
  _globals['_CONSTR']._serialized_start=3401
  _globals['_CONSTR']._serialized_end=3529
  _globals['_BIGINT']._serialized_start=3531
  _globals['_BIGINT']._serialized_end=3630
  _globals['_PLUTUSDATAPAIR']._serialized_start=3633
  _globals['_PLUTUSDATAPAIR']._serialized_end=3763
  _globals['_PLUTUSDATA']._serialized_start=3766
  _globals['_PLUTUSDATA']._serialized_end=4077
  _globals['_PLUTUSDATAMAP']._serialized_start=4079
  _globals['_PLUTUSDATAMAP']._serialized_end=4157
  _globals['_PLUTUSDATAARRAY']._serialized_start=4159
  _globals['_PLUTUSDATAARRAY']._serialized_end=4235
  _globals['_SCRIPT']._serialized_start=4238
  _globals['_SCRIPT']._serialized_end=4383
  _globals['_METADATUM']._serialized_start=4386
  _globals['_METADATUM']._serialized_end=4600
  _globals['_METADATUMARRAY']._serialized_start=4602
  _globals['_METADATUMARRAY']._serialized_end=4676
  _globals['_METADATUMMAP']._serialized_start=4678
  _globals['_METADATUMMAP']._serialized_end=4754
  _globals['_METADATUMPAIR']._serialized_start=4756
  _globals['_METADATUMPAIR']._serialized_end=4883
  _globals['_METADATA']._serialized_start=4885
  _globals['_METADATA']._serialized_end=4975
  _globals['_STAKECREDENTIAL']._serialized_start=4977
  _globals['_STAKECREDENTIAL']._serialized_end=5087
  _globals['_RATIONALNUMBER']._serialized_start=5089
  _globals['_RATIONALNUMBER']._serialized_end=5169
  _globals['_RELAY']._serialized_start=5171
  _globals['_RELAY']._serialized_end=5267
  _globals['_POOLMETADATA']._serialized_start=5269
  _globals['_POOLMETADATA']._serialized_end=5321
  _globals['_CERTIFICATE']._serialized_start=5324
  _globals['_CERTIFICATE']._serialized_end=6044
  _globals['_STAKEDELEGATIONCERT']._serialized_start=6047
  _globals['_STAKEDELEGATIONCERT']._serialized_end=6188
  _globals['_POOLREGISTRATIONCERT']._serialized_start=6191
  _globals['_POOLREGISTRATIONCERT']._serialized_end=6587
  _globals['_POOLRETIREMENTCERT']._serialized_start=6589
  _globals['_POOLRETIREMENTCERT']._serialized_end=6666
  _globals['_GENESISKEYDELEGATIONCERT']._serialized_start=6669
  _globals['_GENESISKEYDELEGATIONCERT']._serialized_end=6815
  _globals['_MIRTARGET']._serialized_start=6817
  _globals['_MIRTARGET']._serialized_end=6944
  _globals['_MIRCERT']._serialized_start=6947
  _globals['_MIRCERT']._serialized_end=7093
  _globals['_ADDRESSPATTERN']._serialized_start=7096
  _globals['_ADDRESSPATTERN']._serialized_end=7225
  _globals['_ASSETPATTERN']._serialized_start=7227
  _globals['_ASSETPATTERN']._serialized_end=7301
  _globals['_TXOUTPUTPATTERN']._serialized_start=7304
  _globals['_TXOUTPUTPATTERN']._serialized_end=7449
  _globals['_TXPATTERN']._serialized_start=7452
  _globals['_TXPATTERN']._serialized_end=7821
  _globals['_EXUNITS']._serialized_start=7823
  _globals['_EXUNITS']._serialized_end=7878
  _globals['_EXPRICES']._serialized_start=7881
  _globals['_EXPRICES']._serialized_end=8019
  _globals['_PROTOCOLVERSION']._serialized_start=8021
  _globals['_PROTOCOLVERSION']._serialized_end=8082
  _globals['_COSTMODEL']._serialized_start=8084
  _globals['_COSTMODEL']._serialized_end=8119
  _globals['_COSTMODELS']._serialized_start=8122
  _globals['_COSTMODELS']._serialized_end=8264
  _globals['_PPARAMS']._serialized_start=8267
  _globals['_PPARAMS']._serialized_end=9601
  _globals['_EVALERROR']._serialized_start=9603
  _globals['_EVALERROR']._serialized_end=9632
  _globals['_EVALTRACE']._serialized_start=9634
  _globals['_EVALTRACE']._serialized_end=9663
  _globals['_TXEVAL']._serialized_start=9666
  _globals['_TXEVAL']._serialized_end=9873
# @@protoc_insertion_point(module_scope)



from google.protobuf import field_mask_pb2 as _field_mask_pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as _cardano_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockRef(_message.Message):
    __slots__ = ("index", "hash")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    index: int
    hash: bytes
    def __init__(self, index: _Optional[int] = ..., hash: _Optional[bytes] = ...) -> None: ...

class AnyChainBlock(_message.Message):
    __slots__ = ("native_bytes", "cardano")
    NATIVE_BYTES_FIELD_NUMBER: _ClassVar[int]
    CARDANO_FIELD_NUMBER: _ClassVar[int]
    native_bytes: bytes
    cardano: _cardano_pb2.Block
    def __init__(self, native_bytes: _Optional[bytes] = ..., cardano: _Optional[_Union[_cardano_pb2.Block, _Mapping]] = ...) -> None: ...

class FetchBlockRequest(_message.Message):
    __slots__ = ("ref", "field_mask")
    REF_FIELD_NUMBER: _ClassVar[int]
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    ref: _containers.RepeatedCompositeFieldContainer[BlockRef]
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, ref: _Optional[_Iterable[_Union[BlockRef, _Mapping]]] = ..., field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class FetchBlockResponse(_message.Message):
    __slots__ = ("block",)
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block: _containers.RepeatedCompositeFieldContainer[AnyChainBlock]
    def __init__(self, block: _Optional[_Iterable[_Union[AnyChainBlock, _Mapping]]] = ...) -> None: ...

class DumpHistoryRequest(_message.Message):
    __slots__ = ("start_token", "max_items", "field_mask")
    START_TOKEN_FIELD_NUMBER: _ClassVar[int]
    MAX_ITEMS_FIELD_NUMBER: _ClassVar[int]
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    start_token: BlockRef
    max_items: int
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, start_token: _Optional[_Union[BlockRef, _Mapping]] = ..., max_items: _Optional[int] = ..., field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DumpHistoryResponse(_message.Message):
    __slots__ = ("block", "next_token")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    block: _containers.RepeatedCompositeFieldContainer[AnyChainBlock]
    next_token: BlockRef
    def __init__(self, block: _Optional[_Iterable[_Union[AnyChainBlock, _Mapping]]] = ..., next_token: _Optional[_Union[BlockRef, _Mapping]] = ...) -> None: ...

class FollowTipRequest(_message.Message):
    __slots__ = ("intersect", "field_mask")
    INTERSECT_FIELD_NUMBER: _ClassVar[int]
    FIELD_MASK_FIELD_NUMBER: _ClassVar[int]
    intersect: _containers.RepeatedCompositeFieldContainer[BlockRef]
    field_mask: _field_mask_pb2.FieldMask
    def __init__(self, intersect: _Optional[_Iterable[_Union[BlockRef, _Mapping]]] = ..., field_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class FollowTipResponse(_message.Message):
    __slots__ = ("apply", "undo", "reset")
    APPLY_FIELD_NUMBER: _ClassVar[int]
    UNDO_FIELD_NUMBER: _ClassVar[int]
    RESET_FIELD_NUMBER: _ClassVar[int]
    apply: AnyChainBlock
    undo: AnyChainBlock
    reset: BlockRef
    def __init__(self, apply: _Optional[_Union[AnyChainBlock, _Mapping]] = ..., undo: _Optional[_Union[AnyChainBlock, _Mapping]] = ..., reset: _Optional[_Union[BlockRef, _Mapping]] = ...) -> None: ...
